@@ -3,13 +3,14 @@ import datetime
 import inspect
 import json
 import pickle
+import uuid
 import warnings
 from dataclasses import dataclass, field, fields, is_dataclass
 from decimal import Decimal
 from enum import Enum
 from typing import Any, Generic, Iterable, TypeVar, Union
+
 import boto3
-import uuid
 
 
 class TableInterface(metaclass=abc.ABCMeta):
@@ -336,7 +337,6 @@ class DynamoCrudRepository(CrudRepository):
     map_dict: map = None
     map_filled: bool = False
     print_debug: bool = False
-    create_table_if_not_exists: bool = False
 
     @staticmethod
     def ITEM2INSTANCE():
@@ -353,17 +353,26 @@ class DynamoCrudRepository(CrudRepository):
     def __init__(
         self,
         entity_type: T,
-        drop_table: bool = False,
         print_debug: bool = False,
         use_mock_db: bool = False,
-        create_table_if_not_exists: bool = True
     ):
         self.entity_type = entity_type
         self.print_debug = print_debug
-        self.create_table_if_not_exists = create_table_if_not_exists
+
+        self.map_dict = self.entity_type.dynamo_map()
+        self._fill_map_dict(self.entity_type)
+
         global_values = DynamoDBGlobalParameters.get_instance()
+        # For a single table design, define the table name as a global parameter,
+        # if the table name is not set in the global parameters, will use the entity class table name
+        if global_values.single_table is not None:
+            self.table_name = global_values.single_table
+        else:
+            self.table_name = self.entity_type.dynamo_table_name()
         if use_mock_db:
             self.ddb = SimulatedDynamoDBResource()
+            if (self.ddb.Table(self.table_name)) is None:
+                self.create_table()  # The table does not exists in the mock dynamodb
         else:
             try:
                 if not global_values.use_aws_cli_credentials:
@@ -381,43 +390,16 @@ class DynamoCrudRepository(CrudRepository):
                 print(ex)
                 raise ConnectionRefusedError("Not able to connect to DynamoDB")
 
-        self.map_dict = self.entity_type.dynamo_map()
-        self._fill_map_dict(self.entity_type)
-
-        # For a single table design, define the table name as a global parameter,
-        # if the table name is not set in the global parameters, will use the entity class table name
-        if global_values.single_table is not None:
-            self.table_name = global_values.single_table
-        else:
-            self.table_name = self.entity_type.dynamo_table_name()
         try:
             self.table = self.ddb.Table(self.table_name)
         except Exception as ex:
             print(ex)
-            if self.create_table_if_not_exists:
-                self.create_table()
-
-        if drop_table:
-            try:
-                if hasattr(self.table, "table_status") and (
-                    self.table.table_status != "DELETING"
-                ):
-                    self.if_debug_print("Table found and will be deleted")
-                    self.table.delete()
-            except Exception as ex:
-                print(ex)
-
-        try:
-            if (
-                not hasattr(self.table, "table_status")
-                or self.table.table_status == "DELETING"
-            ) and self.create_table_if_not_exists:
-                self.if_debug_print("Table not found and will be created")
-                self.create_table()
-        # If the table is not created, the interpreter issues an exception when we try to access the item_count
-        except Exception:
-            if self.create_table_if_not_exists:
-                self.create_table()
+            warning_str = (
+                "Could not access table "
+                + str(self.table_name)
+                + " check if the table exists"
+            )
+            raise ResourceWarning(warning_str)
 
     def create_table(self):
         global_values = DynamoDBGlobalParameters.get_instance()
@@ -1020,7 +1002,7 @@ if __name__ == "__main__":
     counter = Counter()
     # To use local dynamo call DynamoDBGlobalParameters.get_instance(use_aws_cli_credentials=False)
     sample_crud = DynamoCrudRepository(
-        SampleEntityClass, print_debug=True, use_mock_db=True, drop_table=True, create_table_if_not_exists=True
+        SampleEntityClass, print_debug=True, use_mock_db=True
     )
 
     aMap = SampleEntityClass.dynamo_map()
